@@ -351,6 +351,13 @@ class CloudConfig(object):
                 constructor_kwargs['api_version'] = version
             else:
                 constructor_kwargs['version'] = version
+        if service_key == 'database':
+            # TODO(mordred) Remove when https://review.openstack.org/314032
+            # has landed and released. We're passing in a Session, but the
+            # trove Client object has username and password as required
+            # args
+            constructor_kwargs['username'] = None
+            constructor_kwargs['password'] = None
 
         return client_class(**constructor_kwargs)
 
@@ -445,12 +452,36 @@ class CloudConfig(object):
             net['name'] for net in self.config['networks']
             if net['routes_externally']]
 
+    def get_external_ipv4_networks(self):
+        """Get list of network names for external IPv4 networks."""
+        return [
+            net['name'] for net in self.config['networks']
+            if net['routes_ipv4_externally']]
+
+    def get_external_ipv6_networks(self):
+        """Get list of network names for external IPv6 networks."""
+        return [
+            net['name'] for net in self.config['networks']
+            if net['routes_ipv6_externally']]
+
     def get_internal_networks(self):
         """Get list of network names for internal networks."""
         return [
             net['name'] for net in self.config['networks']
             if not net['routes_externally']]
 
+    def get_internal_ipv4_networks(self):
+        """Get list of network names for internal IPv4 networks."""
+        return [
+            net['name'] for net in self.config['networks']
+            if not net['routes_ipv4_externally']]
+
+    def get_internal_ipv6_networks(self):
+        """Get list of network names for internal IPv6 networks."""
+        return [
+            net['name'] for net in self.config['networks']
+            if not net['routes_ipv6_externally']]
+
     def get_default_network(self):
         """Get network used for default interactions."""
         for net in self.config['networks']:
